import { getChallenges, getRecord, getChallenge } from './utils';
import Table from 'cli-table3';
const open = require('open');

export async function challenges(args) {
    let subCmd = 'list';

    try {
        if (args._[1]) {
            subCmd = args._[1];
        }
    } catch (error) {
    }

    switch (subCmd) {
        case 'list':
            await printChallenges();
            break;

        case 'open':
            openChallenge(args);
            break;

        default:
            console.error(`challenges ${subCmd} is not a valid command!`);
            console.error(`Try: nodechron help ${args._[0]}`);
            break;
    }

}


async function printChallenges() {

    var records = await getChallenges();

    const table = new Table({
        head: ['Challenge #', 'Name', 'Description', 'Link'],
        colWidths: [11, 20, 50, 50],
        wordWrap: true
    });

    for (let index = 0; index < records.length; index++) {
        const record = records[index];

        table.push([
            record.get('challengeNumber'),
            record.get('challengeName'),
            record.get('challengeDescription'),
            record.get('challengePermalink')
        ]);
    }

    console.log(table.toString());

}

// args[2] should contain the challenge number
async function openChallenge(args) {

    if (args._.length <= 2) {
        console.error(`nodechron ${args._[0]} ${args._[1]} is not a valid command! (Are you missing the challenge number?)`);
        return;
    }

    var challenge;
    try {
        if (args._[2]) {
            challenge = Number(args._[2]);
            if (isNaN(challenge)) {
                throw ("dummy");
            }
        }
    } catch (error) {
        console.error(`nodechron ${args._[0]} ${args._[1]} ${args._[2]} is not a valid command!`);
        console.error(`Try: nodechron help ${args._[0]}`);
        return;
    }

    var records = await getChallenge(challenge);

    if (records.length > 0) {

        if (!!records[0].get('challengePermalink')) {
            console.log(`Opening challenge ${challenge} in your default browser`);
            open(records[0].get('challengePermalink'));
        } else {
            console.error(`Sorry, challenge ${challenge} does not have a link`);
            return;
        }
    } else {
        console.error(`Sorry, we could not find challenge ${challenge}`);
        return;
    }

}
