import minimist from 'minimist';
import { help } from './help';
import { version } from './version';
import { moments } from './moments';
import { symbols } from './symbols';
import { challenges } from './challenges';
import { episodes } from './episodes';
const got = require('got');


const terminalImage = require('terminal-image');

export async function cli(argsArray) {

    try {

        try {
            // enable this code if we want an image instead of an ascii art to be displayed
            // the image source can be set in the printImage() function itself
            // if (!await printImage()) {
                printLogo();
            // }
        } catch (error) {
            // noop, bad luck we could not display the logo
        }

        const args = minimist(argsArray.slice(2));

        // console.debug(args);

        let cmd = args._[0] || 'help';

        if (args.version || args.v) {
            cmd = 'version';
        }

        if (args.help || args.h) {
            cmd = 'help';
        }

        switch (cmd) {
            case 'version':
                version(args);
                break;

            case 'help':
                help(args);
                break;

            case 'episodes':
                episodes(args);
                break;

            case 'moments':
                moments(args);
                break;

            case 'symbols':
                symbols(args);
                break;

            case 'challenges':
                challenges(args);
                break;

            default:
                console.error(`"${cmd}" is not a valid command!`);
                console.error(`Please try any of the below`);
                help(args);
                break;
        }

    } catch (error) {
        console.error(`that is not a valid command!`);
    }

}

async function printImage() {
    try {
        const body = await got('https://cdn.shopify.com/s/files/1/0096/5243/7056/files/node-logo-big_400x.png?v=1608508958').buffer();
        const image = await terminalImage.buffer(body);
        console.log(image);
    } catch (error) {
        return false;
    }
    return true;
}

function printLogo() {
    console.log(
        `                                                                                
                                MMMM M   M MMMM                                 
                                  M  M   M M                                    
                                  M  MMMMM MMM                                  
                                  M  M   M M                                    
                                  M  M   M MMMM                                 
                                                                               
                      MMMM MMM                     MMMMMMM                      
                      MMMMMMMM DMMMMMMM  MMMMMMMM  MMMMMMM                      
                      MMMMMMMM DMM   MMM MMM  MMMM MMM                          
                      MMM NMMM DMM   MMM MMM   MMM MMM                          
                      MMM  MMM DMM   MMM MMM   MMM MMMMMM                       
                      MMM  MMM DMM   MMM MMM   MMM MMM                          
                      MMM  MMM DMM   MMM MMM   MMM MMM                          
                      MMM  MMM DMM   MMM MMM   MMM MMM                          
                      MMM  MMM DMM   MMM MMM   MMM MMM                          
                      MMM  MMM DMMMMMMMM MMMMMMMMM MMMMMMM                      
   MMMMMMMMM               MMM   MMMMMMM MMMMMMM   MMMMMMM           MMMMMMMM   
  MMMNMMMMMM                                                        MMMMMMMMM   
  MMM  MMD  MMM MMMMMMMM                           MMMM  MM  MMMMMM MMM   MMM   
  MMM  MMD  MMM MMM  MMM~ MMMMMMM  MMMM  MMM MMM MMMMMM  MM  MMMMMM MMM   MMM   
  MMM  MMD  MMM MMM   MM~ MMD  MMM MMMMMMMMM MMM MMM     MM  MMM    MMMMM       
  MMM  MMD  MMM MMM   MM~ MMD  MMM MMMMMMMMM MMM MMM     MM  MMM     MMMMMMM?   
  MMM  MMN  MMM MMM   MM~ MMD  MMM MMM ,MMMM MMM MMM     MM  MMMMM~      MMMM   
  MMM  MMMMMMMM MMM   MM~ MMD  MMM MMM   MMM MMM MMM     MM  MMMMM~ MMM   MMM   
  MMM  MMMMMMMM MMM   MM~ MMD  MMM MMM   MMM MMM MMM     MM  MMM    MMM   MMM   
  MMM  MMD  MMM MMMMMMMM~ MMD  MMM MMM   MMM MMM MMM     MM  MMM    MMM   MMM   
  MMM  MMD  MMM MMMMMMM   MM8  MMM MMM   MMM MMM MMM     MM  MMM    MMM   MMM   
  MMM  MMD  MMM MMMMMMM   MMMMMMMM MMM   MMM MMM MMM     MM  MMM    MMM   MMM   
  MMM  MMD  MMM MMM ZMMM   MMMMMMM MMM   MMM MMM  MMMMM  MM  MMMMMM MMM   MMM   
  MMM           MMM   MMMM                         MMMM  MM  MMMMMM MMM   MMM   
  MMMMMMMMMM           MMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMM  MMMMMMMMMM MMMMMMMMM   
    MMMMMMMM            ~MMMMMMMMMMMMMMMMMMMMMMMMMMMMMM  MMMMMMMMMM MMMMMMM     
                                                                               
`
    )
}
