import { getEpisodes, getEpisode } from './utils';
import Table from 'cli-table3';

const open = require('open');

export async function episodes(args) {

    // console.debug(args);

    let subCmd = 'list';

    try {
        if (args._[1]) {
            subCmd = args._[1];
        }
    } catch (error) {
    }

    switch (subCmd) {
        case 'list':
            await printEpisodes();
            break;

        case 'open':
            openEpisode(args);
            break;

        default:
            console.error(`episodes ${subCmd} is not a valid command!`);
            console.error(`Try: nodechron help ${args._[0]}`);
            break;
    }

}

// args[2] should contain the episode number
async function openEpisode(args) {

    if (args._.length <= 2) {
        console.error(`nodechron ${args._[0]} ${args._[1]} is not a valid command! (Are you missing the episode parameter?)`);
        return;
    }

    var episode;
    try {
        if (args._[2]) {
            episode = Number(args._[2]);
            if (isNaN(episode)) {
                throw ("dummy");
            }
        }
    } catch (error) {
        console.error(`nodechron ${args._[0]} ${args._[1]} ${args._[2]} is not a valid command!`);
        console.error(`Try: nodechron help ${args._[0]}`);
        return;
    }

    var records = await getEpisode(episode);

    if (records.length > 0) {

        if (!!records[0].get('episodePermalink')) {
            console.log(`Opening episode ${episode} in your default browser`);
            open(records[0].get('episodePermalink'));
        } else {
            console.error(`Sorry, episode ${episode} does not have a link`);
            return;
        }
    } else {
        console.error(`Sorry, we could not find episode ${episode}`);
        return;
    }

}


async function printEpisodes() {

    var records = await getEpisodes();

    const table = new Table({
        head: ['Episode #', 'Title', 'Description', '# of Moments', '# of Symbols', 'Link'],
        colWidths: [9, 20, 40, 9, 9, 40],
        wordWrap: true
    });

    for (let index = 0; index < records.length; index++) {
        const record = records[index];

        table.push([
            record.get('episodeNumber'),
            record.get('episodeName'),
            record.get('episodeShortDescription'),
            record.get('episodeMoments') ? record.get('episodeMoments').length : 0,
            record.get('episodeSymbols') ? record.get('episodeSymbols').length : 0,
            record.get('episodePermalink')
        ]);
    }

    console.log(table.toString());

}
