import { getMoments, getRecord, getMoment } from './utils';
import Table from 'cli-table3';
const open = require('open');


export async function moments(args) {
    // console.debug(args);

    let subCmd = 'list';

    try {
        if (args._[1]) {
            subCmd = args._[1];
        }
    } catch (error) {
    }

    switch (subCmd) {
        case 'list':
            await printMoments();
            break;

        case 'open':
            openMoment(args);
            break;

        default:
            console.error(`moments ${subCmd} is not a valid command!`);
            console.error(`Try: nodechron help ${args._[0]}`);
            break;
    }

}

// REQUIREMENT IS:
// [Moment #, Name, Description, Link]
async function printMoments() {

    var records = await getMoments();

    // fields: ["momentName", "momentShortDescription", "Symbols", "momentPermalink", "Episodes"]
    // console.debug("records: ", records);

    const table = new Table({
        head: ['Moment #', 'Name', 'Description', 'Moment Link'],
        colWidths: [9, 20, 50, 50],
        wordWrap: true
    });

    for (let index = 0; index < records.length; index++) {
        const record = records[index];

        // there is no need for episode name for now, so I'm commenting this code below
        // const episodeRecord = await getRecord(record.get('Episodes')[0], 'Episodes');
        // const episodeName = episodeRecord.fields.episodeName;

        table.push([
            record.get('momentNumber'),
            record.get('momentName'),
            record.get('momentShortDescription'),
            record.get('momentPermalink')
        ]);
    }

    console.log(table.toString());

}


// args[2] should contain the moment number
async function openMoment(args) {

    if (args._.length <= 2) {
        console.error(`nodechron ${args._[0]} ${args._[1]} is not a valid command! (Are you missing the moment number?)`);
        return;
    }

    var moment;
    try {
        if (args._[2]) {
            moment = Number(args._[2]);
            if (isNaN(moment)) {
                throw ("dummy");
            }
        }
    } catch (error) {
        console.error(`nodechron ${args._[0]} ${args._[1]} ${args._[2]} is not a valid command!`);
        console.error(`Try: nodechron help ${args._[0]}`);
        return;
    }

    var records = await getMoment(moment);

    if (records.length > 0) {

        if (!!records[0].get('momentPermalink')) {
            console.log(`Opening moment ${moment} in your default browser`);
            open(records[0].get('momentPermalink'));
        } else {
            console.error(`Sorry, moment ${moment} does not have a link`);
            return;
        }
    } else {
        console.error(`Sorry, we could not find moment ${moment}`);
        return;
    }

}
