import { getSymbols, getRecord, getSymbol } from './utils';
import Table from 'cli-table3';
const open = require('open');


export async function symbols(args) {
    let subCmd = 'list';

    try {
        if (args._[1]) {
            subCmd = args._[1];
        }
    } catch (error) {
    }

    switch (subCmd) {
        case 'list':
            await printSymbols();
            break;

        case 'open':
            openSymbol(args);
            break;

        default:
            console.error(`symbols ${subCmd} is not a valid command!`);
            console.error(`Try: nodechron help ${args._[0]}`);
            break;
    }
}

// REQUIREMENT IS:
// [Name, Description, Moment Name, Episode Name, Link]
async function printSymbols() {

    // fields: ["symbolNumber", "symbolName", "symbolShortDescription", "symbolParentMoment", "Episodes", "symbolPermalink"]
    var records = await getSymbols();

    const table = new Table({
        head: ['Symbol #', 'Name', 'Description', 'Moment Name', 'Episode Name', 'Link'],
        colWidths: [8, 20, 50, 20, 20, 50],
        wordWrap: true
    });

    for (let index = 0; index < records.length; index++) {
        const record = records[index];

        // console.log("record.get('Episodes')[0]", record.get('Episodes')[0]);

        let episodeName = "";
        if (record.get('Episodes')) {
            const episodeRecord = await getRecord(record.get('Episodes')[0], 'Episodes');
            if (episodeRecord) {
                episodeName = episodeRecord.fields.episodeName;
            }
        }

        let momentName = "";
        if (record.get('symbolParentMoment')) {
            const momentRecord = await getRecord(record.get('symbolParentMoment')[0], 'Moments');
            if (momentRecord) {
                momentName = momentRecord.fields.momentName;
            }
        }


        table.push([
            record.get('symbolNumber'),
            record.get('symbolName'),
            record.get('symbolShortDescription'),
            momentName,
            episodeName,
            record.get('symbolPermalink')
        ]);
    }

    console.log(table.toString());

}


// args[2] should contain the symbol number
async function openSymbol(args) {

    if (args._.length <= 2) {
        console.error(`nodechron ${args._[0]} ${args._[1]} is not a valid command! (Are you missing the symbol number?)`);
        return;
    }

    var symbol;
    try {
        if (args._[2]) {
            symbol = Number(args._[2]);
            if (isNaN(symbol)) {
                throw ("dummy");
            }
        }
    } catch (error) {
        console.error(`nodechron ${args._[0]} ${args._[1]} ${args._[2]} is not a valid command!`);
        console.error(`Try: nodechron help ${args._[0]}`);
        return;
    }

    var records = await getSymbol(symbol);

    if (records.length > 0) {

        if (!!records[0].get('symbolPermalink')) {
            console.log(`Opening symbol ${symbol} in your default browser`);
            open(records[0].get('symbolPermalink'));
        } else {
            console.error(`Sorry, symbol ${symbol} does not have a link`);
            return;
        }
    } else {
        console.error(`Sorry, we could not find symbol ${symbol}`);
        return;
    }

}
